Class: NBA::CumeStatsPlayerTotal

Inherits:
Shale::Mapper
  • Object
show all
Defined in:
lib/nba/cume_stats_player_total.rb

Overview

Represents cumulative total statistics for a player across multiple games

Instance Attribute Summary collapse

Instance Attribute Details

#actual_minutesInteger

Returns the total minutes played

Examples:

total.actual_minutes #=> 175


63
# File 'lib/nba/cume_stats_player_total.rb', line 63

attribute :actual_minutes, Shale::Type::Integer

#actual_secondsInteger

Returns the total seconds played

Examples:

total.actual_seconds #=> 42


71
# File 'lib/nba/cume_stats_player_total.rb', line 71

attribute :actual_seconds, Shale::Type::Integer

#astInteger

Returns the total assists

Examples:

total.ast #=> 25


175
# File 'lib/nba/cume_stats_player_total.rb', line 175

attribute :ast, Shale::Type::Integer

#avg_astFloat

Returns the average assists per game

Examples:

total.avg_ast #=> 5.0


311
# File 'lib/nba/cume_stats_player_total.rb', line 311

attribute :avg_ast, Shale::Type::Float

#avg_blkFloat

Returns the average blocks per game

Examples:

total.avg_blk #=> 1.0


343
# File 'lib/nba/cume_stats_player_total.rb', line 343

attribute :avg_blk, Shale::Type::Float

#avg_drebFloat

Returns the average defensive rebounds per game

Examples:

total.avg_dreb #=> 6.0


295
# File 'lib/nba/cume_stats_player_total.rb', line 295

attribute :avg_dreb, Shale::Type::Float

#avg_fg3aFloat

Returns the average three-point field goals attempted per game

Examples:

total.avg_fg3a #=> 8.0


263
# File 'lib/nba/cume_stats_player_total.rb', line 263

attribute :avg_fg3a, Shale::Type::Float

#avg_fg3mFloat

Returns the average three-point field goals made per game

Examples:

total.avg_fg3m #=> 3.0


255
# File 'lib/nba/cume_stats_player_total.rb', line 255

attribute :avg_fg3m, Shale::Type::Float

#avg_fgaFloat

Returns the average field goals attempted per game

Examples:

total.avg_fga #=> 20.0


247
# File 'lib/nba/cume_stats_player_total.rb', line 247

attribute :avg_fga, Shale::Type::Float

#avg_fgmFloat

Returns the average field goals made per game

Examples:

total.avg_fgm #=> 10.0


239
# File 'lib/nba/cume_stats_player_total.rb', line 239

attribute :avg_fgm, Shale::Type::Float

#avg_ftaFloat

Returns the average free throws attempted per game

Examples:

total.avg_fta #=> 8.0


279
# File 'lib/nba/cume_stats_player_total.rb', line 279

attribute :avg_fta, Shale::Type::Float

#avg_ftmFloat

Returns the average free throws made per game

Examples:

total.avg_ftm #=> 7.0


271
# File 'lib/nba/cume_stats_player_total.rb', line 271

attribute :avg_ftm, Shale::Type::Float

#avg_minFloat

Returns the average minutes per game

Examples:

total.avg_min #=> 35.0


223
# File 'lib/nba/cume_stats_player_total.rb', line 223

attribute :avg_min, Shale::Type::Float

#avg_orebFloat

Returns the average offensive rebounds per game

Examples:

total.avg_oreb #=> 2.0


287
# File 'lib/nba/cume_stats_player_total.rb', line 287

attribute :avg_oreb, Shale::Type::Float

#avg_pfFloat

Returns the average personal fouls per game

Examples:

total.avg_pf #=> 3.0


319
# File 'lib/nba/cume_stats_player_total.rb', line 319

attribute :avg_pf, Shale::Type::Float

#avg_ptsFloat

Returns the average points per game

Examples:

total.avg_pts #=> 30.0


351
# File 'lib/nba/cume_stats_player_total.rb', line 351

attribute :avg_pts, Shale::Type::Float

#avg_secFloat

Returns the average seconds per game

Examples:

total.avg_sec #=> 8.4


231
# File 'lib/nba/cume_stats_player_total.rb', line 231

attribute :avg_sec, Shale::Type::Float

#avg_stlFloat

Returns the average steals per game

Examples:

total.avg_stl #=> 2.0


327
# File 'lib/nba/cume_stats_player_total.rb', line 327

attribute :avg_stl, Shale::Type::Float

#avg_tot_rebFloat

Returns the average total rebounds per game

Examples:

total.avg_tot_reb #=> 8.0


303
# File 'lib/nba/cume_stats_player_total.rb', line 303

attribute :avg_tot_reb, Shale::Type::Float

#avg_tovFloat

Returns the average turnovers per game

Examples:

total.avg_tov #=> 3.0


335
# File 'lib/nba/cume_stats_player_total.rb', line 335

attribute :avg_tov, Shale::Type::Float

#blkInteger

Returns the total blocks

Examples:

total.blk #=> 5


207
# File 'lib/nba/cume_stats_player_total.rb', line 207

attribute :blk, Shale::Type::Integer

#drebInteger

Returns the total defensive rebounds

Examples:

total.dreb #=> 30


159
# File 'lib/nba/cume_stats_player_total.rb', line 159

attribute :dreb, Shale::Type::Integer

#fg3_pctFloat

Returns the three-point field goal percentage

Examples:

total.fg3_pct #=> 0.375


119
# File 'lib/nba/cume_stats_player_total.rb', line 119

attribute :fg3_pct, Shale::Type::Float

#fg3aInteger

Returns the total three-point field goals attempted

Examples:

total.fg3a #=> 40


111
# File 'lib/nba/cume_stats_player_total.rb', line 111

attribute :fg3a, Shale::Type::Integer

#fg3mInteger

Returns the total three-point field goals made

Examples:

total.fg3m #=> 15


103
# File 'lib/nba/cume_stats_player_total.rb', line 103

attribute :fg3m, Shale::Type::Integer

#fg_pctFloat

Returns the field goal percentage

Examples:

total.fg_pct #=> 0.500


95
# File 'lib/nba/cume_stats_player_total.rb', line 95

attribute :fg_pct, Shale::Type::Float

#fgaInteger

Returns the total field goals attempted

Examples:

total.fga #=> 100


87
# File 'lib/nba/cume_stats_player_total.rb', line 87

attribute :fga, Shale::Type::Integer

#fgmInteger

Returns the total field goals made

Examples:

total.fgm #=> 50


79
# File 'lib/nba/cume_stats_player_total.rb', line 79

attribute :fgm, Shale::Type::Integer

#ft_pctFloat

Returns the free throw percentage

Examples:

total.ft_pct #=> 0.875


143
# File 'lib/nba/cume_stats_player_total.rb', line 143

attribute :ft_pct, Shale::Type::Float

#ftaInteger

Returns the total free throws attempted

Examples:

total.fta #=> 40


135
# File 'lib/nba/cume_stats_player_total.rb', line 135

attribute :fta, Shale::Type::Integer

#ftmInteger

Returns the total free throws made

Examples:

total.ftm #=> 35


127
# File 'lib/nba/cume_stats_player_total.rb', line 127

attribute :ftm, Shale::Type::Integer

#gpInteger

Returns the games played

Examples:

total.gp #=> 5


47
# File 'lib/nba/cume_stats_player_total.rb', line 47

attribute :gp, Shale::Type::Integer

#gsInteger

Returns the games started

Examples:

total.gs #=> 5


55
# File 'lib/nba/cume_stats_player_total.rb', line 55

attribute :gs, Shale::Type::Integer

#jersey_numString

Returns the jersey number

Examples:

total.jersey_num #=> "30"


31
# File 'lib/nba/cume_stats_player_total.rb', line 31

attribute :jersey_num, Shale::Type::String

#max_astInteger

Returns the maximum assists in a game

Examples:

total.max_ast #=> 10


439
# File 'lib/nba/cume_stats_player_total.rb', line 439

attribute :max_ast, Shale::Type::Integer

#max_blkInteger

Returns the maximum blocks in a game

Examples:

total.max_blk #=> 3


471
# File 'lib/nba/cume_stats_player_total.rb', line 471

attribute :max_blk, Shale::Type::Integer

#max_drebInteger

Returns the maximum defensive rebounds in a game

Examples:

total.max_dreb #=> 10


423
# File 'lib/nba/cume_stats_player_total.rb', line 423

attribute :max_dreb, Shale::Type::Integer

#max_fg3aInteger

Returns the maximum three-point field goals attempted in a game

Examples:

total.max_fg3a #=> 12


391
# File 'lib/nba/cume_stats_player_total.rb', line 391

attribute :max_fg3a, Shale::Type::Integer

#max_fg3mInteger

Returns the maximum three-point field goals made in a game

Examples:

total.max_fg3m #=> 8


383
# File 'lib/nba/cume_stats_player_total.rb', line 383

attribute :max_fg3m, Shale::Type::Integer

#max_fgaInteger

Returns the maximum field goals attempted in a game

Examples:

total.max_fga #=> 25


375
# File 'lib/nba/cume_stats_player_total.rb', line 375

attribute :max_fga, Shale::Type::Integer

#max_fgmInteger

Returns the maximum field goals made in a game

Examples:

total.max_fgm #=> 15


367
# File 'lib/nba/cume_stats_player_total.rb', line 367

attribute :max_fgm, Shale::Type::Integer

#max_ftaInteger

Returns the maximum free throws attempted in a game

Examples:

total.max_fta #=> 12


407
# File 'lib/nba/cume_stats_player_total.rb', line 407

attribute :max_fta, Shale::Type::Integer

#max_ftmInteger

Returns the maximum free throws made in a game

Examples:

total.max_ftm #=> 10


399
# File 'lib/nba/cume_stats_player_total.rb', line 399

attribute :max_ftm, Shale::Type::Integer

#max_minInteger

Returns the maximum minutes in a game

Examples:

total.max_min #=> 42


359
# File 'lib/nba/cume_stats_player_total.rb', line 359

attribute :max_min, Shale::Type::Integer

#max_orebInteger

Returns the maximum offensive rebounds in a game

Examples:

total.max_oreb #=> 5


415
# File 'lib/nba/cume_stats_player_total.rb', line 415

attribute :max_oreb, Shale::Type::Integer

#max_pfInteger

Returns the maximum personal fouls in a game

Examples:

total.max_pf #=> 5


447
# File 'lib/nba/cume_stats_player_total.rb', line 447

attribute :max_pf, Shale::Type::Integer

#max_ptsInteger

Returns the maximum points in a game

Examples:

total.max_pts #=> 45


479
# File 'lib/nba/cume_stats_player_total.rb', line 479

attribute :max_pts, Shale::Type::Integer

#max_rebInteger

Returns the maximum total rebounds in a game

Examples:

total.max_reb #=> 12


431
# File 'lib/nba/cume_stats_player_total.rb', line 431

attribute :max_reb, Shale::Type::Integer

#max_stlInteger

Returns the maximum steals in a game

Examples:

total.max_stl #=> 4


455
# File 'lib/nba/cume_stats_player_total.rb', line 455

attribute :max_stl, Shale::Type::Integer

#max_tovInteger

Returns the maximum turnovers in a game

Examples:

total.max_tov #=> 5


463
# File 'lib/nba/cume_stats_player_total.rb', line 463

attribute :max_tov, Shale::Type::Integer

#orebInteger

Returns the total offensive rebounds

Examples:

total.oreb #=> 10


151
# File 'lib/nba/cume_stats_player_total.rb', line 151

attribute :oreb, Shale::Type::Integer

#pfInteger

Returns the total personal fouls

Examples:

total.pf #=> 15


183
# File 'lib/nba/cume_stats_player_total.rb', line 183

attribute :pf, Shale::Type::Integer

#player_idInteger

Returns the player ID

Examples:

total.player_id #=> 201939


15
# File 'lib/nba/cume_stats_player_total.rb', line 15

attribute :player_id, Shale::Type::Integer

#player_nameString

Returns the player name

Examples:

total.player_name #=> "Stephen Curry"


23
# File 'lib/nba/cume_stats_player_total.rb', line 23

attribute :player_name, Shale::Type::String

#ptsInteger

Returns the total points

Examples:

total.pts #=> 150


215
# File 'lib/nba/cume_stats_player_total.rb', line 215

attribute :pts, Shale::Type::Integer

#seasonString

Returns the season

Examples:

total.season #=> "2024-25"


39
# File 'lib/nba/cume_stats_player_total.rb', line 39

attribute :season, Shale::Type::String

#stlInteger

Returns the total steals

Examples:

total.stl #=> 10


191
# File 'lib/nba/cume_stats_player_total.rb', line 191

attribute :stl, Shale::Type::Integer

#tot_rebInteger

Returns the total rebounds

Examples:

total.tot_reb #=> 40


167
# File 'lib/nba/cume_stats_player_total.rb', line 167

attribute :tot_reb, Shale::Type::Integer

#tovInteger

Returns the total turnovers

Examples:

total.tov #=> 15


199
# File 'lib/nba/cume_stats_player_total.rb', line 199

attribute :tov, Shale::Type::Integer