Class: NBA::DraftCombineAnthroMeasurement

Inherits:
Shale::Mapper
  • Object
show all
Defined in:
lib/nba/draft_combine_anthro_measurement.rb

Overview

Represents a draft combine anthropometric measurement

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#body_fat_pctFloat

Returns the body fat percentage

Examples:

measurement.body_fat_pct #=> 4.8


135
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 135

attribute :body_fat_pct, Shale::Type::Float

#first_nameString

Returns the player’s first name

Examples:

measurement.first_name #=> "Victor"


31
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 31

attribute :first_name, Shale::Type::String

#hand_lengthFloat

Returns the hand length in inches

Examples:

measurement.hand_length #=> 10.25


143
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 143

attribute :hand_length, Shale::Type::Float

#hand_widthFloat

Returns the hand width in inches

Examples:

measurement.hand_width #=> 12.0


151
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 151

attribute :hand_width, Shale::Type::Float

#height_w_shoesFloat

Returns the height with shoes in inches

Examples:

measurement.height_w_shoes #=> 86.5


79
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 79

attribute :height_w_shoes, Shale::Type::Float

#height_w_shoes_ft_inString

Returns the height with shoes in feet and inches

Examples:

measurement.height_w_shoes_ft_in #=> "7' 2.5\""


87
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 87

attribute :height_w_shoes_ft_in, Shale::Type::String

#height_wo_shoesFloat

Returns the height without shoes in inches

Examples:

measurement.height_wo_shoes #=> 85.5


63
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 63

attribute :height_wo_shoes, Shale::Type::Float

#height_wo_shoes_ft_inString

Returns the height without shoes in feet and inches

Examples:

measurement.height_wo_shoes_ft_in #=> "7' 1.5\""


71
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 71

attribute :height_wo_shoes_ft_in, Shale::Type::String

#last_nameString

Returns the player’s last name

Examples:

measurement.last_name #=> "Wembanyama"


39
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 39

attribute :last_name, Shale::Type::String

#player_idInteger

Returns the player ID

Examples:

measurement.player_id #=> 1630162


23
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 23

attribute :player_id, Shale::Type::Integer

#player_nameString

Returns the player name

Examples:

measurement.player_name #=> "Victor Wembanyama"


47
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 47

attribute :player_name, Shale::Type::String

#positionString

Returns the player’s position

Examples:

measurement.position #=> "C"


55
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 55

attribute :position, Shale::Type::String

#standing_reachFloat

Returns the standing reach in inches

Examples:

measurement.standing_reach #=> 114.5


119
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 119

attribute :standing_reach, Shale::Type::Float

#standing_reach_ft_inString

Returns the standing reach in feet and inches

Examples:

measurement.standing_reach_ft_in #=> "9' 6.5\""


127
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 127

attribute :standing_reach_ft_in, Shale::Type::String

#temp_player_idInteger

Returns the temporary player ID

Examples:

measurement.temp_player_id #=> 123456


15
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 15

attribute :temp_player_id, Shale::Type::Integer

#weightFloat

Returns the weight in pounds

Examples:

measurement.weight #=> 209.0


95
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 95

attribute :weight, Shale::Type::Float

#wingspanFloat

Returns the wingspan in inches

Examples:

measurement.wingspan #=> 96.0


103
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 103

attribute :wingspan, Shale::Type::Float

#wingspan_ft_inString

Returns the wingspan in feet and inches

Examples:

measurement.wingspan_ft_in #=> "8' 0\""


111
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 111

attribute :wingspan_ft_in, Shale::Type::String

Instance Method Details

#playerPlayer?

Returns the player object

Examples:

measurement.player #=> #<NBA::Player>


159
160
161
# File 'lib/nba/draft_combine_anthro_measurement.rb', line 159

def player
  Players.find(player_id)
end