Module: NBA::ShotChartLineupDetail
- Defined in:
- lib/nba/shot_chart_lineup_detail.rb
Overview
Provides methods to retrieve NBA shot chart lineup detail
Constant Summary collapse
- DETAIL_SET =
Result set name for shot chart lineup detail
"ShotChartLineupDetail".freeze
- AVERAGE_SET =
Result set name for league averages
"ShotChartLineupLeagueAverage".freeze
Class Method Summary collapse
-
.all(group_id:, season: Utils.current_season, season_type: "Regular Season", context_measure: "FGA", period: 0, league: League::NBA, client: CLIENT) ⇒ Collection
Retrieves shot chart lineup detail for a lineup group.
Class Method Details
.all(group_id:, season: Utils.current_season, season_type: "Regular Season", context_measure: "FGA", period: 0, league: League::NBA, client: CLIENT) ⇒ Collection
Retrieves shot chart lineup detail for a lineup group
34 35 36 37 38 39 40 41 42 |
# File 'lib/nba/shot_chart_lineup_detail.rb', line 34 def self.all(group_id:, season: Utils.current_season, season_type: "Regular Season", context_measure: "FGA", period: 0, league: League::NBA, client: CLIENT) league_id = Utils.extract_league_id(league) opts = {group_id: group_id, season: season, season_type: season_type, context_measure: context_measure, period: period, league_id: league_id} ResponseParser.parse(client.get(build_path(opts)), result_set: DETAIL_SET) do |data| build_shot(data) end end |