Module: NBA::PlayerCareerByCollegeRollup
- Defined in:
- lib/nba/player_career_by_college_rollup.rb
Overview
Provides methods to retrieve player career stats aggregated by college region
Constant Summary collapse
- PER_GAME =
Per mode constant for per game stats
"PerGame".freeze
- TOTALS =
Per mode constant for totals
"Totals".freeze
- EAST =
Result set name for East region colleges
"East".freeze
- MIDWEST =
Result set name for Midwest region colleges
"Midwest".freeze
- SOUTH =
Result set name for South region colleges
"South".freeze
- WEST =
Result set name for West region colleges
"West".freeze
Class Method Summary collapse
-
.east(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from East region colleges.
-
.midwest(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from Midwest region colleges.
-
.south(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from South region colleges.
-
.west(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from West region colleges.
Class Method Details
.east(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from East region colleges
43 44 45 46 |
# File 'lib/nba/player_career_by_college_rollup.rb', line 43 def self.east(per_mode: TOTALS, season: nil, client: CLIENT) path = build_path(per_mode, season) ResponseParser.parse(client.get(path), result_set: EAST) { |data| build_stat(data) } end |
.midwest(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from Midwest region colleges
59 60 61 62 |
# File 'lib/nba/player_career_by_college_rollup.rb', line 59 def self.midwest(per_mode: TOTALS, season: nil, client: CLIENT) path = build_path(per_mode, season) ResponseParser.parse(client.get(path), result_set: MIDWEST) { |data| build_stat(data) } end |
.south(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from South region colleges
75 76 77 78 |
# File 'lib/nba/player_career_by_college_rollup.rb', line 75 def self.south(per_mode: TOTALS, season: nil, client: CLIENT) path = build_path(per_mode, season) ResponseParser.parse(client.get(path), result_set: SOUTH) { |data| build_stat(data) } end |
.west(per_mode: TOTALS, season: nil, client: CLIENT) ⇒ Collection
Retrieves career statistics for players from West region colleges
91 92 93 94 |
# File 'lib/nba/player_career_by_college_rollup.rb', line 91 def self.west(per_mode: TOTALS, season: nil, client: CLIENT) path = build_path(per_mode, season) ResponseParser.parse(client.get(path), result_set: WEST) { |data| build_stat(data) } end |